==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/creative_tab/content/TemplateCreativeTab.java <==
package cc.thonly.reverie_dreams.creative_tab.content;

import cc.thonly.reverie_dreams.Touhou;
import cc.thonly.reverie_dreams.danmaku.DanmakuShape;
import cc.thonly.reverie_dreams.danmaku.DanmakuTypes;
import cc.thonly.reverie_dreams.danmaku.SpellCardTemplates;
import cc.thonly.reverie_dreams.item.ModItems;
import cc.thonly.reverie_dreams.registry.RegistryManager;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1761;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7924;
import java.util.Map;
import java.util.Set;

public class TemplateCreativeTab implements ItemGroupContentHelper {
    public static final class_5321<class_1761> ITEM_GROUP_KEY = class_5321.method_29179(class_7924.field_44688, Touhou.id("item_group_template"));
    public static final class_1761 ITEM_GROUP = ItemGroupContentHelper.builder()
            .method_47320(() -> new class_1799(ModItems.SPELL_CARD_TEMPLATE))
            .method_47321(class_2561.method_43471("item_group.touhou.template"))
            .method_47324();

    public static void bootstrap() {
        ItemGroupEvents.modifyEntriesEvent(TemplateCreativeTab.ITEM_GROUP_KEY).register(itemGroup -> {
            Map<class_2960, class_1799> registryView = SpellCardTemplates.getRegistryItemStackView();
            Set<Map.Entry<class_2960, class_1799>> views = registryView.entrySet();
            for (Map.Entry<class_2960, class_1799> view : views) {
                class_1799 stack = view.getValue();
                itemGroup.method_45420(stack.method_7972());
            }
            for (DanmakuShape shape : RegistryManager.DANMAKU_SHAPE) {
                if (DanmakuTypes.UNLIST.contains(shape.getType())) {
                    continue;
                }
                itemGroup.method_45420(shape.getItemStack());
            }
        });
        ItemGroupContentHelper.registerGroup(TemplateCreativeTab.ITEM_GROUP_KEY, TemplateCreativeTab.ITEM_GROUP);
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/creative_tab/content/TemplateCreativeTab.java <==
package cc.thonly.reverie_dreams.creative_tab.content;

import cc.thonly.reverie_dreams.ReverieDreams;
import cc.thonly.reverie_dreams.data.danmaku.DanmakuShape;
import cc.thonly.reverie_dreams.registry.content.danmaku.DanmakuTypes;
import cc.thonly.reverie_dreams.registry.content.danmaku.DanmakuTemplates;
import cc.thonly.reverie_dreams.registry.content.item.RDItems;
import cc.thonly.reverie_dreams.registry.RegistryHandlers;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1761;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7924;
import java.util.Map;
import java.util.Set;

public class TemplateCreativeTab implements ItemGroupContentHelper {
    public static final class_5321<class_1761> ITEM_GROUP_KEY = class_5321.method_29179(class_7924.field_44688, ReverieDreams.id("item_group_template"));
    public static final class_1761 ITEM_GROUP = ItemGroupContentHelper.builder()
            .method_47320(() -> new class_1799(RDItems.SPELL_CARD_TEMPLATE))
            .method_47321(class_2561.method_43471("item_group.touhou.template"))
            .method_47324();

    public static void bootstrap() {
        ItemGroupEvents.modifyEntriesEvent(TemplateCreativeTab.ITEM_GROUP_KEY).register(itemGroup -> {
            Map<class_2960, class_1799> registryView = DanmakuTemplates.getRegistryItemStackView();
            Set<Map.Entry<class_2960, class_1799>> views = registryView.entrySet();
            for (Map.Entry<class_2960, class_1799> view : views) {
                class_1799 stack = view.getValue();
                itemGroup.method_45420(stack.method_7972());
            }
            for (DanmakuShape shape : RegistryHandlers.DANMAKU_SHAPE) {
                if (DanmakuTypes.UNLIST.contains(shape.getType())) {
                    continue;
                }
                itemGroup.method_45420(shape.getItemStack());
            }
        });
        ItemGroupContentHelper.registerGroup(TemplateCreativeTab.ITEM_GROUP_KEY, TemplateCreativeTab.ITEM_GROUP);
    }
}
